/* Style of the unrevealed tiles after game over */
.explodedField .mine {
  background-color:#888a85;
}

.explodedField .exploded {
  background-color:#d3d7cf;
}

.surrounded-by-1-mines .cursor{
  background-color:shade(#DDFAC3, 0.5);
}

.surrounded-by-2-mines .cursor{
  background-color:shade(#ECEDBF, 0.5);
}

.surrounded-by-3-mines .cursor{
  background-color:shade(#EDDAB4, 0.5);
}

.surrounded-by-4-mines .cursor{
  background-color:shade(#EDC38A, 0.5);
}

.surrounded-by-5-mines .cursor{
  background-color:shade(#F7A1A2, 0.5);
}

.surrounded-by-6-mines .cursor{
  background-color:shade(#FEA785, 0.5);
}

.surrounded-by-7-mines .cursor{
  background-color:shade(#FF7D60, 0.5);
}

.surrounded-by-8-mines .cursor{
  background-color:#FF323C;
}

.surrounded-by-1-mines:not(.cursor) {
  background-color:#DDFAC3;
}

.surrounded-by-2-mines:not(.cursor) {
  background-color:#ECEDBF;
}

.surrounded-by-3-mines:not(.cursor) {
  background-color:#EDDAB4;
}

.surrounded-by-4-mines:not(.cursor) {
  background-color:#EDC38A;
}

.surrounded-by-5-mines:not(.cursor) {
  background-color:#F7A1A2;
}

.surrounded-by-6-mines:not(.cursor) {
  background-color:#FEA785;
}

.surrounded-by-7-mines:not(.cursor) {
  background-color:#FF7D60;
}

.surrounded-by-8-mines:not(.cursor) {
  background-color:#FF323C;
}
